@@ -3,7 +3,6 @@ from ftis.common.io import write_json, read_json
 from ftis.common.proc import staticproc
 from umap import UMAP as umapdr
 from joblib import dump as jdump
-
 import numpy as np
 
 
@@ -31,10 +30,11 @@ class UMAP(FTISAnalyser):
 
         data = np.array(data)
 
-        self.model = umapdr(n_components=self.components, n_neighbors=self.neighbours, min_dist=self.mindist, random_state=42)
+        self.model = umapdr(
+            n_components=self.components, n_neighbors=self.neighbours, min_dist=self.mindist, random_state=42
+        )
         self.model.fit(data)
         transformed_data = self.model.transform(data)
-
         self.output = {k: v.tolist() for k, v in zip(keys, transformed_data)}
 
     def run(self):
