@@ -5,6 +5,9 @@ from multiprocessing import Manager
 from scipy.signal import savgol_filter
 from scipy.io import wavfile
 from sklearn.cluster import AgglomerativeClustering
+from sklearn.preprocessing import StandardScaler
+from flucoma import fluid
+from flucoma.utils import get_buffer
 import numpy as np
 
 
@@ -40,7 +43,10 @@ class ClusteredNMF(FTISAnalyser):
 
     def analyse(self, workable):
         nmf = fluid.nmf(
-            workable, iterations=self.iterations, components=self.components, fftsettings=self.fftsettings,
+            workable,
+            iterations=self.iterations,
+            components=self.components,
+            fftsettings=self.fftsettings,
         )
         bases = get_buffer(nmf.bases, "numpy")
         bases_smoothed = np.zeros_like(bases)
@@ -78,10 +84,12 @@ class ClusteredNMF(FTISAnalyser):
 
 
 class ClusteredSegmentation(FTISAnalyser):
-    def __init__(self, numclusters=2, windowsize=4, cache=False):
+    def __init__(self, numclusters=2, windowsize=4, numderivs=0, fftsettings=[1024, -1 -1], cache=False):
         super().__init__(cache=cache)
         self.numclusters = numclusters
         self.windowsize = windowsize
+        self.derivates = numderivs
+        self.fftsettings = fftsettings 
         self.dump_type = ".json"
 
     def load_cache(self):
@@ -91,7 +99,7 @@ class ClusteredSegmentation(FTISAnalyser):
         write_json(self.dump_path, self.output)
 
     def analyse(self, workable):
-        slices = self.input[workable]
+        slices = self.input[str(workable)]
         slices = [int(x) for x in slices]
         if len(slices) == 1:
             self.buffer[workable] = slices
@@ -105,9 +113,14 @@ class ClusteredSegmentation(FTISAnalyser):
             data = []
             for i, (start, end) in enumerate(zip(indices, indices[1:])):
 
-                mfcc = mfcc(workable, fftsettings=[2048, -1, -1], startframe=start, numframes=end - start,)
+                mfccs = fluid.mfcc(
+                    workable,
+                    fftsettings=self.fftsettings,
+                    startframe=start,
+                    numframes=end - start,
+                )
 
-                stats = get_buffer(stats(mfcc, numderivs=1), "numpy")
+                stats = get_buffer(fluid.stats(mfccs, numderivs=self.numderivs), "numpy")
 
                 data.append(stats.flatten())
 
@@ -128,6 +141,5 @@ class ClusteredSegmentation(FTISAnalyser):
 
     def run(self):
         self.buffer = Manager().dict()
-        workables = [x for x in self.input]
-        singleproc(self.name, self.analyse, workables)
+        singleproc(self.name, self.analyse, self.input)
         self.output = dict(self.buffer)
