@@ -25,7 +25,6 @@ def create_hash(*items) -> str:
         m.update(str(item).encode("utf-8"))
     return m.hexdigest()
 
-
 ignored_keys = (  # keys to ignore from superclass
     "process",
     "dump_path",
@@ -38,4 +37,6 @@ ignored_keys = (  # keys to ignore from superclass
     "cache_possible",
     "corpus_items",
     "buffer",
+    "pre", "post",
+    "scripting", "chain", "parent", "parent_string"
 )
